let createAsyncLocalStorage;
if (process.env.NEXT_RUNTIME === "edge") {
    createAsyncLocalStorage = ()=>{
        let store;
        return {
            disable () {
                throw new Error("Invariant: AsyncLocalStorage accessed in runtime where it is not available");
            },
            getStore () {
                return store;
            },
            async run (s, fn) {
                store = s;
                try {
                    return await fn();
                } finally{
                    store = undefined;
                }
            },
            exit () {
                throw new Error("Invariant: AsyncLocalStorage accessed in runtime where it is not available");
            },
            enterWith () {
                throw new Error("Invariant: AsyncLocalStorage accessed in runtime where it is not available");
            }
        };
    };
} else {
    createAsyncLocalStorage = require("./async-local-storage").createAsyncLocalStorage;
}
export const actionAsyncStorage = createAsyncLocalStorage();

//# sourceMappingURL=action-async-storage.js.map